@@ -1,34 +1,20 @@
-### cherry.R (2005-06-30)
+### cherry.R (2006-10-03)
 ###
 ###     Number of Cherries and Null Models of Trees
 ###
-### Copyright 2002-2005 Emmanuel Paradis
+### Copyright 2002-2006 Emmanuel Paradis
 ###
-### This file is part of the `ape' library for R and related languages.
-### It is made available under the terms of the GNU General Public
-### License, version 2, or at your option, any later version,
-### incorporated herein by reference.
-###
-### This program is distributed in the hope that it will be
-### useful, but WITHOUT ANY WARRANTY; without even the implied
-### warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
-### PURPOSE.  See the GNU General Public License for more
-### details.
-###
-### You should have received a copy of the GNU General Public
-### License along with this program; if not, write to the Free
-### Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
-### MA 02111-1307, USA
+### This file is part of the R-package `ape'.
+### See the file ../COPYING for licensing issues.
 
 cherry <- function(phy)
 {
     if (class(phy) != "phylo") stop("object \"phy\" is not of class \"phylo\"")
-    tmp <- as.numeric(phy$edge)
-    n <- max(tmp)
-    nb.node <- -min(tmp)
+    n <- length(phy$tip.label)
+    nb.node <- phy$Nnode
     if (nb.node != n - 1) stop("\"phy\" is not fully dichotomous")
     if (n < 4) stop("not enough tips in your phylogeny for this analysis")
-    cherry <- sum(table(phy$edge[, 1][as.numeric(phy$edge[, 2]) > 0]) == 2)
+    cherry <- sum(tabulate(phy$edge[, 1][phy$edge[, 2] <= n]) == 2)
     small.n <- if (n < 20) TRUE else FALSE
     if (small.n) {
         P.yule <- f.cherry.yule(n, cherry)
